#!/usr/bin/python

# publish-or-perish.py
# By Fred Ollinger
# (C) GPL 3.0

import urwid.curses_display
import urwid
import datetime
import time
import sys

class Clock(object):
	def now(self):
		t = datetime.datetime.now()
		return time.mktime(t.timetuple())

	def __init__(self):
		t = datetime.datetime.now()
		self.nowsec=time.mktime(t.timetuple())
		self.ttime = 5*60

	def getstr(self):
		t = self.now()
		dif = t-self.nowsec
		tleft = self.ttime - dif
		min = tleft/60
		mleft = int(tleft/60)
		frac = min - mleft 
		sec = int(frac * 60)
		if mleft < 10:
			mleft = str("0") + str(mleft)
		if sec < 0:
			sec = str("00") 
		if sec < 10:
			sec = str("0") + str(sec)
		if min < 0:
			mleft = str("00") 
		t = str(mleft) + ":" + str(sec)
		return t

	def getint(self):
		t = self.now()
		dif = t-self.nowsec
		tleft = self.ttime - dif
		return tleft

class Conversation(object):
	def __init__(self):
		print len(sys.argv)
		if len(sys.argv) < 2:
			print "Please specify a filename!"
			sys.exit(1)

		self.fn = sys.argv[1] # filename

		self.items = urwid.SimpleListWalker(
			[self.new_question()])
		self.listbox = urwid.ListBox(self.items)
		self.instruct = urwid.Text("Press F8 to exit. F1 to save.")
		header = urwid.AttrWrap( self.instruct, 'header' )
		self.top = urwid.Frame(self.listbox, header)
		# variable holds last time person was writing
		self.writing = datetime.datetime.now() 

	def savef(self, fn, data):
		FILE = open(fn,"a")
		FILE.writelines(data)
		FILE.close()

	def main(self):
		self.c = Clock()
		self.ui = urwid.curses_display.Screen()
		self.ui.register_palette([
			('header', 'black', 'dark cyan', 'standout'),
			('I say', 'default', 'default', 'bold'),
			])
		self.ui.run_wrapper( self.run )
	
	def run(self):
		size = self.ui.get_cols_rows()
		self.writing = self.c.getint()
		ct = 0

		while True:
			self.draw_screen( size )
			keys = self.ui.get_input()
			s = self.c.getstr()
			s = str(s) + "  Word Count: " + str(ct)
			t = self.c.getint()
			lapse = self.writing - t
	
			self.draw_screen( size )
			# debugging to show whether person was writing or not
			if "f1" in keys:
				name = self.items[0].edit_text
				self.savef(self.fn, name)

			if "f7" in keys:
				self.instruct.set_text(str(lapse))
				
			if "f8" in keys:
				name = self.items[0].edit_text
				self.savef(self.fn, name)
				break

			if " " in keys:
				ct = ct + 1

			for k in keys:
				if k == "window resize":
					size = self.ui.get_cols_rows()
					continue
				self.top.keypress( size, k )
				# update timer to make sure person was writing
				self.writing = self.c.getint()
			if keys:
				name = self.items[0].edit_text
				
			if lapse > 30:
				self.instruct.set_text("Game Over!!  You Lose!!")
				continue

			if lapse > 20:
				self.instruct.set_text("I mean it!!  Start Writing!!")
				continue

			# check to see if the game is over
			if t < 1:
				self.instruct.set_text("You Win!!")
			elif lapse > 10:
				self.instruct.set_text("Come on! Start Writing!!!!")
			else:
				self.instruct.set_text(s)
	
	def draw_screen(self, size):
		canvas = self.top.render( size, focus=True )
		self.ui.draw_screen( size, canvas )

	def new_question(self):
		return urwid.Edit()

	def new_answer(self, name):
		return urwid.Text(('I say',"Nice to meet you, "+name+"\n"))

Conversation().main()
